/*
 * %kadu copyright begin%
 * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
 * %kadu copyright end%
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include "plugin-state.h"

#include <QtCore/QString>

QString pluginStateToString(PluginState pluginState)
{
	switch (pluginState)
	{
		case PluginState::Enabled:
			return QStringLiteral("Loaded");
		case PluginState::Disabled:
			return QStringLiteral("NotLoaded");
		default:
			return {};
	}
}

PluginState stringToPluginState(const QString &string)
{
	if (string == QStringLiteral("Loaded"))
		return PluginState::Enabled;
	else if (string == QStringLiteral("NotLoaded"))
		return PluginState::Disabled;
	else
		return PluginState::New;
}
